#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
Este script inicia el seeder "bittornado" (o lo reinicia, si ya estuviera iniciado), finalizando previamente cualquier proceso activo.
En principio, debería hacer lo mismo que la sección correspondiente del script "/etc/init.d/opengnsys", que se ejecuta al inicio (pero que debería dejar de hacerlo).
Creemos que debe ser llamado únicamente cuando se quiera hacer una descarga mediante P2P (junto al script "runTorrentTracker.py").

No recibe ningún parámetro.
"""

# --------------------------------------------------------------------------------------------
#                                        IMPORTS
# --------------------------------------------------------------------------------------------

import os
import sys
import subprocess
from systemd import journal


# --------------------------------------------------------------------------------------------
#                                        VARIABLES
# --------------------------------------------------------------------------------------------

repo_path = '/opt/opengnsys/ogrepository/images' # En este caso, no lleva barra final


# --------------------------------------------------------------------------------------------
#                                        FUNCTIONS
# --------------------------------------------------------------------------------------------


def run_bittornado(repo_path):
    """ Ejecuta el comando "btlaunchmany.bittornado", con sus parámetros correspondientes.
        Además, captura el resultado y los posibles errores, y los imprime.
    """
    # Creamos una lista con el comando "btlaunchmany.bittornado" y sus parámetros, y lo imprimimos con espacios:
    splitted_cmd = f"btlaunchmany.bittornado {repo_path}".split()
    print(f"Sending command: {' '.join(splitted_cmd)}")
    journal.send(f"runTorrentSeeder.py: Running command: {' '.join(splitted_cmd)}", PRIORITY=journal.LOG_INFO, SYSLOG_IDENTIFIER="ogrepo-api_DEBUG")

    # Ejecutamos el comando "btlaunchmany.bittornado" en el sistema, e imprimimos el resultado:
    try:
        result = subprocess.run(splitted_cmd, check=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
        journal.send(f"runTorrentSeeder.py: Command ReturnCode: {result.returncode}", PRIORITY=journal.LOG_INFO, SYSLOG_IDENTIFIER="ogrepo-api_DEBUG")
        print(f"Bittornado ReturnCode: {result.returncode}")
    except subprocess.CalledProcessError as error:
        journal.send("runTorrentSeeder.py: Process finalized", PRIORITY=journal.LOG_WARNING, SYSLOG_IDENTIFIER="ogrepo-api_DEBUG")
        print(f"Bittornado ReturnCode: {error.returncode}")
        print(f"Bittornado Error Output: {error.stderr.decode()}")
    except Exception as error:
        journal.send(f"runTorrentSeeder.py: Command exception: {error}", PRIORITY=journal.LOG_ERR, SYSLOG_IDENTIFIER="ogrepo-api_DEBUG")
        print(f"Unexpected bittornado error: {error}")



# --------------------------------------------------------------------------------------------
#                                          MAIN
# --------------------------------------------------------------------------------------------


def main():
    """
    """
    # Finalizamos el proceso "btlaunchmany.bittornado" (en caso de que estuviera corriendo):
    try:
        journal.send("runTorrentSeeder.py: Killing process 'btlaunchmany.bittornado'...", PRIORITY=journal.LOG_INFO, SYSLOG_IDENTIFIER="ogrepo-api_DEBUG")
        subprocess.run(f"pkill btlaunchmany".split(), check=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
    except Exception as error_description:
        journal.send("runTorrentSeeder.py: No 'btlaunchmany.bittornado' process running", PRIORITY=journal.LOG_INFO, SYSLOG_IDENTIFIER="ogrepo-api_DEBUG")
        print(f"No btlaunchmany.bittornado process running? Returned error: {error_description}")

    # Ejecutamos el comando "btlaunchmany.bittornado" (para hacer seed de los torrents):
    run_bittornado(repo_path)



# --------------------------------------------------------------------------------------------

if __name__ == "__main__":
    main()

# --------------------------------------------------------------------------------------------
